==> haskell-silently-1.2.5.1-5-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-silently.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 silently
version:              1.2.5.1
visibility:           public
id:                   silently-1.2.5.1-E4eD0MmjyzKB1P5OuTUdMs
key:                  silently-1.2.5.1-E4eD0MmjyzKB1P5OuTUdMs
license:              BSD-3-Clause
copyright:            (c) Trystan Spangler 2011
maintainer:
    Sönke Hahn <soenkehahn@gmail.com>, Simon Hengel <sol@typeful.net>

author:               Trystan Spangler
homepage:             https://github.com/hspec/silently
package-url:          https://github.com/hspec/silently
synopsis:             Prevent or capture writing to stdout and other handles.
description:          Prevent or capture writing to stdout and other handles.
category:             System, Testing
abi:                  ed6739a1204cf076537297279bb55cb4
exposed:              True
exposed-modules:      System.IO.Silently
import-dirs:          /usr/lib/ghc-8.8.3/site-local/silently-1.2.5.1
library-dirs:         /usr/lib/ghc-8.8.3/site-local/silently-1.2.5.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.8.3/silently-1.2.5.1
hs-libraries:         HSsilently-1.2.5.1-E4eD0MmjyzKB1P5OuTUdMs
depends:              base-4.13.0.0 deepseq-1.4.4.0 directory-1.3.6.0
haddock-interfaces:   /usr/share/doc/haskell-silently/html/silently.haddock
haddock-html:         /usr/share/doc/haskell-silently/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-silently-1.2.5.1-6-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-silently.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 silently
version:              1.2.5.1
visibility:           public
id:                   silently-1.2.5.1-1ROLHzUF7i4svDXdlqKlI
key:                  silently-1.2.5.1-1ROLHzUF7i4svDXdlqKlI
license:              BSD-3-Clause
copyright:            (c) Trystan Spangler 2011
maintainer:
    Sönke Hahn <soenkehahn@gmail.com>, Simon Hengel <sol@typeful.net>

author:               Trystan Spangler
homepage:             https://github.com/hspec/silently
package-url:          https://github.com/hspec/silently
synopsis:             Prevent or capture writing to stdout and other handles.
description:          Prevent or capture writing to stdout and other handles.
category:             System, Testing
abi:                  b14f0345bf68edc3d44d1cb35b4cf6a1
exposed:              True
exposed-modules:      System.IO.Silently
import-dirs:          /usr/lib/ghc-8.10.1/site-local/silently-1.2.5.1
library-dirs:         /usr/lib/ghc-8.10.1/site-local/silently-1.2.5.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.1/silently-1.2.5.1
hs-libraries:         HSsilently-1.2.5.1-1ROLHzUF7i4svDXdlqKlI
depends:              base-4.14.0.0 deepseq-1.4.4.0 directory-1.3.6.0
haddock-interfaces:   /usr/share/doc/haskell-silently/html/silently.haddock
haddock-html:         /usr/share/doc/haskell-silently/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
